@@ -16,7 +16,7 @@ from testflows._core.test import Module, Suite, Test, Step, NullStep
 from testflows._core.test import TestStep, TestCase, TestSuite, TestModule, TestBackground, TestOutline
 from testflows._core.test import Context
 from testflows._core.test import Feature, Background, Scenario, Example, Outline
-from testflows._core.test import Check, Given, When, Then, And, But, By, Finally
+from testflows._core.test import Critical, Major, Minor, Check, Given, When, Then, And, But, By, Finally
 from testflows._core.test import TestFeature, TestScenario, TestCheck, loads, ordered
 from testflows._core.has import has
 from testflows._core.flags import Flags
@@ -44,7 +44,11 @@ from testflows._core.flags import MANDATORY, CLEAR
 from testflows._core.flags import EANY, ERESULT, XRESULT
 from testflows._core.flags import PARALLEL, NO_PARALLEL
 from testflows._core import __author__, __version__, __license__
-from testflows._core.parallel import Pool, join, top, current, previous
+from testflows._core.parallel import join, top, current, previous
+
+import testflows.core.parallel as parallel
+import testflows.core.objects as objects
+import testflows.core.name as name
 
 import testflows._core.utils as utils
-import testflows._core.contrib.rsa as rsa
\ No newline at end of file
+import testflows._core.contrib.rsa as rsa
